#  DAO Track

## Description

A DAO (Decentralized Autonomous Organization) services pre-defined goals - groups use it to reduce coordination failure and improve collaboration, security. It is an organization managed in whole or in part by decentralized computer program(s), with reputation system, voting and resoures handled through a blockchain. 

How would that look like as a DAO, on top of Substrate? Or Gear Protocol is enough? Or just cryptography?

## What to do on this track?

You need to implement a DAO structure. You can use all technologies existing in the Polkadot ecosystem, however Substrate is preferred.

Topics you can choose from:
1.  __Educational DAO__ - Every organization needs education, some of them are heavily focused on that specific aspect. Can we replace MOOCs, academies or universities with a DAO or these would be important parts of it? Create a DAO that incentivizes the participants to learn and teach each others about Web3. Consider the human factors, different roles, resources and how those would be handled to have a long-term future, topology, incentives, risks.
2.  __Government DAO__ - How could a country work as a DAO? Create a system that provides basic funcionality for your imaginary decentralized country. Tip: you can use OpenGov or QRUCIAL DAO's reputation system in your implementation. Consider the following: How would people interact with the system? What incentivizes the members to keep running as a DAO? How do you avoid centralization efficiently? What are the risks and anti-fraud mechanisms?
3.  __Turn an existing project DAO__ - Choose a project from the Polkadot ecosystem and work out how it could continue as a DAO. You can choose any of the already existing parachains (those that are not DAOs). Examples: Mosaic Chain, Interlay, Mandala Chain or CCTF. You can use all existing services, but need to implement the exact thing(s) that would turn these into DAOs.

The submission will be evaluated based on the strength of the idea and the delivered proof of concept code. Substrate or Gear Protocal are preferred, but not a must - you can use EVM too. We give you a very free hand over the idea and the implementation, but it needs to be realistic and useful for the ecosystem.

## References

https://en.wikipedia.org/wiki/Decentralized_autonomous_organization

https://github.com/deltaDAO/awesome-dao

Remember: Polkadot is also a DAO basically, but without the legal structure.


# Security and Privacy track

## Description

This track is about improving the security and privacy of the ecosystem.

## What to do on this track?

Choose one from the list and implement a meaningful system related to this track's topic:

- Gear / VARA - https://www.gear-tech.io/
- Sygma - https://buildwithsygma.com/
- SubWallet - https://www.subwallet.app/
- DCTF / CCTF - https://git.hsbp.org/CCTF/DCTF
- Mandala Chain - https://www.mandalachain.io/
- Substrate - https://substrate.io/
- Your own privacy protecting implementation that is pluggable to most Web3 systems.

The project you deliver needs to have seamless integration (to wherever it applies), should not make the systems too complicated to use or manage. ZK and pure cryptographic implementations are preferred. You can think about ideas like: When you see someone's message, how can you verify it is really from that person, eg. in news/web3 socials/etc? How can you catch malicious activity on blockchain, for example in games? How to stop fraud? How to tell someone s/he is allowed to do something without revealing their identity?

The submission will be evaluated based on the strength of the idea and the delivered proof of concept code.We give you a very free hand over the idea and the implementation, but it needs to be realistic and useful for the ecosystem.


# AI Blockchain track

## Description and task

Is this a crazy idea or there could be realistic and meaningful implementations where AI is running on top of blockchain? Leave the buzzwords behind and look into the technology, code and math: find a way if blockchain+AI can make any sense. Think about Polkadot's Coretime model and ZK possibilities as well.

The submission will be evaluated based on the strength of the idea and the delivered proof of concept code.We give you a very free hand over the idea and the implementation, but it needs to be realistic and useful.

## References
https://wiki.apillon.io/ - You can use Apillon for your infrastructure.

https://wiki.polkadot.network/docs/polkadot-direction

https://www.youtube.com/watch?v=VwLGGYhGkL8

https://www.ibm.com/topics/blockchain-ai